﻿(* Raima.Rdm is the system module that contains the ADO.NET data provider
   for RDM *)
open Raima.Rdm

(* EXAMPLE - Hello World for F# using ADO.NET *)
(* Each time you run this example, a new record is created in the
 * database, then all existing records are read from the database
 * and printed.
 * 
 * The following methods are illustrated:
 *     Raima.Rdm.RdmConnection:
 *         Close() Method
 *         CreateCommand() Method
 *         Open() Method
 *         RdmConnection(String) Constructor
 *     Raima.Rdm.RdmCommand:
 *         CommandText Property
 *         ExecuteNonQuery() Method
 *         ExecuteReader() Method
 *     Raima.Rdm.RdmDataReader:
 *         Item[int] Property
 *         Read() Method
 * 
 * They are fully document in http://docs.raima.com/rdm/.
 * 
 * For simplicity this example does not catch any thrown execptions
 * but good programming practices would dictate that this occur in
 * a full application.
 *)

let CreateDatabase =
    let conn = new RdmConnection("host=local")
    conn.Open()

    let cmd = conn.CreateCommand()

    try
        cmd.CommandText <- "CREATE DATABASE HelloWorld"
        cmd.ExecuteNonQuery() |> ignore

        cmd.CommandText <- "CREATE TABLE HelloTab (message CHAR(30))"
        cmd.ExecuteNonQuery() |> ignore

        cmd.CommandText <- "COMMIT"
        cmd.ExecuteNonQuery() |> ignore
    with
        | exn -> ()

    conn.Close()

CreateDatabase

(* Create the connection with a simple connection string *)
let conn = new RdmConnection("host=local;database=HelloWorld;openmode=x")

(* Open the connection to the database *)
conn.Open()

(* Create a new command and set its text to insert a row *)
let cmd = conn.CreateCommand()
cmd.CommandText <- "INSERT INTO HelloTab VALUES 'Hello World'"

(* Execute the command, inserting a new row *)
cmd.ExecuteNonQuery() |> ignore

(* Scan through all the existing records and print out the contents *)
cmd.CommandText <- "SELECT message from HelloTab"
let reader = cmd.ExecuteReader()

while (reader.Read()) do
    printfn "%s" (string (reader.Item(0)))

conn.Close()

printfn "Hit <Enter> to continue"
System.Console.ReadLine() |> ignore

